/**
 * Modified from nbdime
 * https://github.com/jupyter/nbdime/blob/master/packages/labextension/src/widget.ts
 */
import { Toolbar } from '@jupyterlab/apputils';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { Message } from '@lumino/messaging';
import { Panel, Widget } from '@lumino/widgets';
import { NotebookDiffModel } from 'nbdime/lib/diff/model';
import { NotebookDiffWidget } from 'nbdime/lib/diff/widget';
import { Git } from '../../tokens';
/**
 * Class of the root of the actual diff, the scroller element
 */
export declare const ROOT_CLASS = "nbdime-root";
/**
 * Diff callback to be registered for notebook files.
 *
 * @param model Diff model
 * @param toolbar MainAreaWidget toolbar
 * @returns Diff notebook widget
 */
export declare const createNotebookDiff: (model: Git.Diff.IModel<string>, renderMime: IRenderMimeRegistry, toolbar?: Toolbar<Widget>) => Promise<NotebookDiff>;
/**
 * NotebookDiff widget
 */
export declare class NotebookDiff extends Panel implements Git.Diff.IDiffWidget {
    constructor(model: Git.Diff.IModel<string>, renderMime: IRenderMimeRegistry);
    /**
     * Whether the unchanged cells are hidden or not
     */
    get areUnchangedCellsHidden(): boolean;
    set areUnchangedCellsHidden(v: boolean);
    /**
     * Promise which fulfills when the widget is ready.
     */
    get ready(): Promise<void>;
    /**
     * Refresh diff
     *
     * Note: Update the content and recompute the diff
     */
    refresh(): Promise<void>;
    protected createDiffView(model: NotebookDiffModel, renderMime: IRenderMimeRegistry): NotebookDiffWidget;
    /**
     * Handle `'activate-request'` messages.
     */
    protected onActivateRequest(msg: Message): void;
    /**
     * Display an error instead of the file diff
     *
     * @param error Error object
     */
    protected showError(error: Error): void;
    protected _areUnchangedCellsHidden: boolean;
    protected _isReady: Promise<void>;
    protected _model: Git.Diff.IModel<string>;
    protected _renderMime: IRenderMimeRegistry;
    protected _scroller: Panel;
}
