import { Widget } from '@lumino/widgets';
import { MergeView } from 'codemirror';
import { Git } from '../../tokens';
/**
 * Diff callback to be registered for plain-text files.
 *
 * @param model Diff model
 * @param toolbar MainAreaWidget toolbar
 * @returns PlainText diff widget
 */
export declare const createPlainTextDiff: Git.Diff.ICallback<string>;
/**
 * Plain Text Diff widget
 */
export declare class PlainTextDiff extends Widget implements Git.Diff.IDiffWidget {
    constructor(model: Git.Diff.IModel<string>);
    /**
     * Promise which fulfills when the widget is ready.
     */
    get ready(): Promise<void>;
    /**
     * Callback to create the diff widget once the widget
     * is attached so CodeMirror get proper size.
     */
    onAfterAttach(): void;
    /**
     * Undo onAfterAttach
     */
    onBeforeDetach(): void;
    /**
     * Refresh diff
     *
     * Note: Update the content and recompute the diff
     */
    refresh(): Promise<void>;
    /**
     * Create wrapper node
     */
    protected static createNode(baseLabel: string, remoteLabel: string): HTMLElement;
    /**
     * Create the Plain Text Diff view
     */
    protected createDiffView(): Promise<void>;
    /**
     * Display an error instead of the file diff
     *
     * @param error Error object
     */
    protected showError(error: Error): void;
    protected static getDefaultOptions(): Partial<MergeView.MergeViewEditorConfiguration>;
    protected _container: HTMLElement;
    protected _isReady: Promise<void>;
    protected _mergeView: MergeView.MergeViewEditor;
    protected _model: Git.Diff.IModel<string>;
    private _reference;
    private _challenger;
}
