import { IDisposable } from '@lumino/disposable';
import { ISignal } from '@lumino/signaling';
import { Git } from '../../tokens';
/**
 * Base DiffModel class
 */
export declare class DiffModel<T> implements IDisposable, Git.Diff.IModel<T> {
    constructor(props: Omit<Git.Diff.IModel<T>, 'changed'>);
    /**
     * A signal emitted when the model changed.
     *
     * Note: The signal is emitted for any set on reference or
     * on challenger change except for the content; i.e. the content
     * is not fetch to check if it changed.
     */
    get changed(): ISignal<DiffModel<T>, Git.Diff.IModelChange>;
    /**
     * Challenger description
     */
    get challenger(): Git.Diff.IContent<T>;
    set challenger(v: Git.Diff.IContent<T>);
    /**
     * File to be compared
     */
    get filename(): string;
    /**
     * Reference description
     */
    get reference(): Git.Diff.IContent<T>;
    set reference(v: Git.Diff.IContent<T>);
    /**
     * Boolean indicating whether the model has been disposed.
     */
    get isDisposed(): boolean;
    /**
     * Dispose of the model.
     */
    dispose(): void;
    protected _reference: Git.Diff.IContent<T>;
    protected _challenger: Git.Diff.IContent<T>;
    private _changed;
    private _isDisposed;
    private _filename;
}
