import { Signal } from '@lumino/signaling';
/**
 * Base DiffModel class
 */
export class DiffModel {
    constructor(props) {
        this._isDisposed = false;
        this._challenger = props.challenger;
        this._filename = props.filename;
        this._reference = props.reference;
        this._changed = new Signal(this);
    }
    /**
     * A signal emitted when the model changed.
     *
     * Note: The signal is emitted for any set on reference or
     * on challenger change except for the content; i.e. the content
     * is not fetch to check if it changed.
     */
    get changed() {
        return this._changed;
    }
    /**
     * Challenger description
     */
    get challenger() {
        return this._challenger;
    }
    set challenger(v) {
        const emitSignal = this._challenger.label !== v.label ||
            this._challenger.source !== v.source ||
            this._challenger.updateAt !== v.updateAt;
        this._challenger = v;
        if (emitSignal) {
            this._changed.emit({ type: 'challenger' });
        }
    }
    /**
     * File to be compared
     */
    get filename() {
        return this._filename;
    }
    /**
     * Reference description
     */
    get reference() {
        return this._reference;
    }
    set reference(v) {
        const emitSignal = this._reference.label !== v.label ||
            this._reference.source !== v.source ||
            this._reference.updateAt !== v.updateAt;
        this._reference = v;
        if (emitSignal) {
            this._changed.emit({ type: 'reference' });
        }
    }
    /**
     * Boolean indicating whether the model has been disposed.
     */
    get isDisposed() {
        return this._isDisposed;
    }
    /**
     * Dispose of the model.
     */
    dispose() {
        if (this.isDisposed) {
            return;
        }
        this._isDisposed = true;
        Signal.clearData(this);
    }
}
//# sourceMappingURL=model.js.map